@@ -26,9 +26,9 @@ Usage example:
 
 __author__ = """SekouDiaoNlp"""
 __email__ = 'diao.sekou.nlp@gmail.com'
-__version__ = '3.7.19'
-__copyright__ = "Copyright (c) 2017, SekouDiaoNlp"
-__credits__ = ("Pierre Sarrazin",)
+__version__ = '3.7.21'
+__copyright__ = "Copyright (c) 2021, SekouDiaoNlp"
+__credits__ = ("Sekou Diao", "Pierre Sarrazin",)
 __license__ = "MIT"
 __maintainer__ = "SekouDiaoNlp"
 __status__ = "Production"
